package com.hzya.frame.wecom.util;

import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpRequest;
import com.alibaba.fastjson.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import java.time.Instant;

/**
 * @Description 获取企业微信accesToken
 * @Author xiangerlin
 * @Date 2024/9/23 14:08
 **/
public class WeComAccessToken {

    static Logger logger = LoggerFactory.getLogger(WeComAccessToken.class);
    //token
    private static String accessToken;
    //过期时间
    private static Instant expireTime;
    private static final Long CACHE_EXPIRY_TIME = 7000L; // 缓存有效时间（秒）


    /**
     * 获取accessToken
     *
     * @param corpid 企业ID
     * @param corpsecret 	应用的凭证密钥
     * @return
     */
    public static String getAccessToken(String corpid,String corpsecret) {
        //判断是否过期 如果没过期直接返回
        if (null != accessToken && expireTime != null && Instant.now().isBefore(expireTime)) {
            return accessToken;
        }
        //获取新的accessToken
        accessToken = fetchNewAccessToken(corpid,corpsecret);
        //过期时间设置成当前事件+7000s，预留200s的时间
        expireTime = Instant.now().plusSeconds(CACHE_EXPIRY_TIME);
        return accessToken;
    }

    /**
     * 获取信的token
     * @param corpid
     * @param corpsecret
     * @return
     */
    private static String fetchNewAccessToken(String corpid, String corpsecret) {
        String url = " https://qyapi.weixin.qq.com/cgi-bin/gettoken?corpid="+corpid+"&corpsecret="+corpsecret;
        String response = HttpRequest.get(url).timeout(30000).execute().body();
        if (StrUtil.isNotEmpty(response)){
            JSONObject json = JSONObject.parseObject(response);
            String accessToken = json.getString("access_token");
            return accessToken;
        }
        return null;
    }

    public static void main(String[] args) {
        for (int i=0; i<2; i++){
            String accessToken1 = WeComAccessToken.getAccessToken("wwb46c3f5e6ffe3e2b", "oON2ELxNVyl7wc37LeA9bNOsv_jyuFXdrvD9e0yogbQ");
            System.out.println(accessToken1);
        }
    }
}
